@@ -6,8 +6,6 @@ no warnings 'uninitialized';
 
 use lib '/opt/yote/lib';
 use lib '/home/wolf/proj/Yote/ServerYote/lib';
-use lib '/home/wolf/proj/Yote/LockServer/lib';
-use lib '/home/wolf/proj/Yote/FixedRecordStore/lib';
 use lib '/home/wolf/proj/Yote/YoteBase/lib';
 
 use Yote;
@@ -16,6 +14,7 @@ use Yote::Server;
 use CGI;
 use DateTime;
 use Data::Dumper;
+use Encode;
 use JSON;
 use URI::Escape;
 
@@ -40,7 +39,7 @@ my $cgi = CGI->new;
 
 # check if a file upload
 my $json_payload = uri_unescape(scalar($cgi->param('p')));
-
+_log( "IN : '$json_payload'" );
 my $uploads = $cgi->param('f');
 my( @uploads );
 if( $uploads ) {
@@ -70,20 +69,21 @@ eval {
 };
 
 if( ref $@ eq 'HASH' ) {
-    $out_json = to_json( $@ );
+    $out_json = encode_json( $@ );
     undef $@;
 } elsif( $@ ) {
     _log( "ERRY <$@>" );
-    $out_json = to_json( {
+    $out_json = encode_json( {
         err => 'ERROR',
                          } );
 }
 
 print $cgi->header(
     -status => '200 OK',
-    -type => 'text/json'
+    -type => 'text/json; charset=utf-8'
     );
-_log("OUTY <$out_json>");
+$out_json = Encode::decode('utf8',$out_json);
+_log( "CGI OUT <$out_json>" );
 print $out_json;
 $main::yote_server->{STORE}->stow_all;
 
